#ifndef NT2_INCLUDE_FUNCTIONS_LDIVIDE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LDIVIDE_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/ldivide.hpp>

#endif
